.. Copyright 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Tools for unit testing
======================

Run fixtures
^^^^^^^^^^^^

CleanDatabase
"""""""""""""

.. autoclass:: reahl.dev.fixtures.CleanDatabase
   :members:

BrowserSetup
""""""""""""

.. autoclass:: reahl.webdev.fixtures.BrowserSetup
   :members:

Testing tools
^^^^^^^^^^^^^

WidgetTester
""""""""""""

.. autoclass:: reahl.webdev.tools.WidgetTester
   :members:

Browser
"""""""

.. autoclass:: reahl.webdev.tools.Browser
   :members:

XPath
"""""

.. autoclass:: reahl.webdev.tools.XPath
   :members:

ReahlWebServer
""""""""""""""

.. autoclass:: reahl.webdev.webserver.ReahlWebServer
   :members:

DriverBrowser
"""""""""""""

.. autoclass:: reahl.webdev.tools.DriverBrowser
   :members:

